Skip to contents

Convenience function that locates and loads the first .cu3s file found in the sample data directories.

Usage

cuvis_sample_session()

Value

A cuvis_session object, or NULL with a warning if sample data is not found.